@@ -29,6 +29,7 @@ from typing import Tuple
 from fabric_cf.actor.core.manage.error import Error
 from fabric_cf.actor.core.util.id import ID
 from fabric_mb.message_bus.messages.delegation_avro import DelegationAvro
+from fabric_mb.message_bus.messages.slice_avro import SliceAvro
 
 from fabric_mgmt_cli.managecli.show_command import ShowCommand
 
@@ -250,17 +251,24 @@ class ManageCommand(ShowCommand):
             if am_actor is None or broker_actor is None:
                 raise Exception("Invalid arguments am_actor {} or broker_actor {} not found".format(am_actor,
                                                                                                     broker_actor))
+            delegations = []
+            if did is None:
+                delegations, error = self.do_get_delegations(actor_name=am, callback_topic=callback_topic, did=did,
+                                                             id_token=id_token)
+                if delegations is None:
+                    print("Error occurred while getting delegations for actor: {}".format(am))
+                    self.print_result(status=error.get_status())
+                    return
 
-            delegations, error = self.do_get_delegations(actor_name=am, callback_topic=callback_topic, did=did,
-                                                         id_token=id_token)
-            if delegations is None:
-                print("Error occurred while getting delegations for actor: {}".format(am))
-                self.print_result(status=error.get_status())
-                return
-
-            if delegations is None or len(delegations) == 0:
-                print("No delegations to be claimed from {} by {}:".format(am, broker))
-                return
+                if delegations is None or len(delegations) == 0:
+                    print("No delegations to be claimed from {} by {}:".format(am, broker))
+                    return
+            else:
+                dd = DelegationAvro()
+                dd.slice = SliceAvro()
+                dd.slice.slice_name = broker
+                dd.delegation_id = did
+                delegations = [dd]
 
             claimed = False
             for d in delegations:
